@@ -1,5 +1,9 @@
 """Constants."""
 
+from __future__ import annotations
+
+
 Error = "E"
+Fix = "F"
 InterruptingError = "I"
 ResultValue = "R"
