@@ -464,6 +464,23 @@ class JMESPathProjectConfigFunctions(JMESPathFunctions):
     def _func_os(self) -> str:
         return sys.platform
 
+    # Github functions
+    @jmespath_func_signature(
+        {"types": ["string"]},
+        {"types": ["string"], "variadic": True},
+    )
+    def _func_gh_tags(
+        self, repo_owner: str, repo_name: str, *args: t.Any
+    ) -> t.List[str]:
+        from project_config.fetchers.github import get_latest_release_tags
+
+        kwargs = {}
+        if len(args):
+            kwargs["only_semver"] = args[0]
+
+        return get_latest_release_tags(repo_owner, repo_name, **kwargs)
+
+    # built-in Python's functions
     locals().update(
         dict(
             {
@@ -812,6 +829,16 @@ def smart_fixer_by_expected_value(
     if ast["type"] == "field":
         key = ast["value"]
         return f"set(@, '{key}' `{json.dumps(expected_value)}`)"
+    elif ast["type"] == "subexpression":
+        temporal_object = {}
+
+        _obj = {}
+        for i, child in enumerate(reversed(ast["children"])):
+            if i == 0:
+                _obj = {child["value"]: expected_value}
+            else:
+                _obj = {child["value"]: _obj}
+        temporal_object = _obj
     elif ast["type"] == "function_expression" and ast["value"] == "type":
         if expected_value not in REVERSE_JMESPATH_TYPE_PYOBJECT:
             return ""
